@@ -22,7 +22,8 @@ def get_homepath() -> Path:
         if os.environ.get("PYTEST") or Path().cwd().name == "tests":
             return Path("NotImplemented")
         elif Path(SETTINGS_FILENAME) in Path().glob("*"):
-            # # script-master TODO
+            with open(Path() / SETTINGS_FILENAME) as f:
+                data = f.read()
             return Path().cwd()
 
         raise
